#!/bin/csh -f
#
# tutorial script for CNSsolve
#
# written by: Paul Adams
# copyright Yale University
#
set tutdir='doc/html/tutorial'
set lnfiles=(data/nsf/nsf_atp.mtf \
             data/nsf/minimize.pdb \
             data/nsf/atp.top \
             data/nsf/atp.param \
  	     data/nsf/nsf.cv \
  	     data/nsf/mad_phase2.hkl \
	     data/nsf/nsf_o.pdb \
	     refinement_mlhl/rebuild/omac \
             refinement_mlhl/rebuild/model_map_2fofc.inp \
	     refinement_mlhl/rebuild/generate_easy_reb.inp \
	     refinement_mlhl/rebuild/anneal_reb.inp \
	     refinement_mlhl/rebuild/bindividual.inp)
#
if ( ! $?CNS_SOLVE ) then
  echo "CNS_SOLVE not defined"
  echo "CNS must be correctly setup to running this tutorial script"
  exit 1
endif
#
if ( ! -d $CNS_SOLVE/$tutdir ) then
  echo "cannot find tutorial directory $CNS_SOLVE/$tutdir"
  echo "please check that you are using the correct version of CNS"
  exit 1
endif
#
foreach file ( $lnfiles )
  if ( ! -e {$file}:t ) then
    echo "linking $tutdir/$file to current directory"
    ln -s $CNS_SOLVE/$tutdir/$file .
  endif
end
#
echo "        "
echo "running:"
echo "         cns_solve < model_map_2fofc.inp > model_map_2fofc.out"
echo "        "
#
cns_solve < model_map_2fofc.inp > model_map_2fofc.out
#
echo "        "
echo "running:"
echo "         cns_solve < generate_easy_reb.inp > generate_easy_reb.out"
echo "        "
#
cns_solve < generate_easy_reb.inp > generate_easy_reb.out
#
echo "        "
echo "running:"
echo "         cns_solve < anneal_reb.inp > anneal_reb.out"
echo "        "
#
cns_solve < anneal_reb.inp > anneal_reb.out
#
echo "        "
echo "running:"
echo "         cns_solve < bindividual.inp > bindividual.out"
echo "        "
#
cns_solve < bindividual.inp > bindividual.out
#
echo "        "
#
